@@ -1,89 +1,33 @@
-# Marvel ####
+# Classics ####
 
-#' Multilevel two-mode affiliation, signed one-mode networks of Marvel comic
-#' book characters (Yuksel 2017)
+## Adolescents ####
+
+#' One-mode subset of the adolescent society network (Coleman 1961)
 #'
 #' @description
-#' This package includes two datasets related to the Marvel _comic book_ universe.
-#' The first, `ison_marvel_teams`,  is a two-mode affiliation network of 53
-#' Marvel comic book characters and their affiliations to 141 different teams.
-#' This network includes only information about nodes' names and nodeset,
-#' but additional nodal data can be taken from the other Marvel dataset here.
-#'
-#' The second network, `ison_marvel_relationships`, is a one-mode signed network
-#' of friendships and enmities between the 53 Marvel comic book characters.
-#' Friendships are indicated by a positive sign in the tie `sign` attribute,
-#' whereas enmities are indicated by a negative sign in this edge attribute.
-#' @details
-#' Additional nodal variables have been coded and included by Dr Umut Yuksel:
-#'
-#' - **Gender**: binary character, 43 "Male" and 10 "Female"
-#' - **PowerOrigin**: binary character, 2 "Alien", 1 "Cyborg", 5 "God/Eternal",
-#' 22 "Human", 1 "Infection", 16 "Mutant", 5 "Radiation", 1 "Robot"
-#' - **Appearances**: integer, in how many comic book issues they appeared in
-#' - **Attractive**: binary integer, 41 1 (yes) and 12 0 (no)
-#' - **Rich**: binary integer, 11 1 (yes) and 42 0 (no)
-#' - **Intellect**: binary integer, 39 1 (yes) and 14 0 (no)
-#' - **Omnilingual**: binary integer, 8 1 (yes) and 45 0 (no)
-#' - **UnarmedCombat**: binary integer, 51 1 (yes) and 2 0 (no)
-#' - **ArmedCombat**: binary integer, 25 1 (yes) and 28 0 (no)
+#'  One-mode subset of Coleman's adolescent society network (Coleman 1961),
+#'  as used in Feld's (1991) "Why your friends have more friends than you do".
+#'  Coleman collected data on friendships among students in 12 U.S. high schools.
+#'  Feld explored a subset of 8 girls from one of these schools, "Marketville",
+#'  and gave them fictitious names, which are retained here.
 #' @docType data
 #' @keywords datasets
-#' @name ison_marvel
-#' @usage data(ison_marvel_teams)
-#' @source Umut Yuksel, 31 March 2017
-#' @format
-#'   ```{r, echo = FALSE}
-#'   ison_marvel_teams
-#'   ```
-"ison_marvel_teams"
-
-#' @rdname ison_marvel
-#' @usage data(ison_marvel_relationships)
-#' @format
-#'   ```{r, echo = FALSE}
-#'   ison_marvel_relationships
-#'   ```
-"ison_marvel_relationships"
-
-# Lord of the Rings ####
-
-#' One-mode network of Lord of the Rings character interactions
+#' @name ison_adolescents
+#' @usage data(ison_adolescents)
+#' @references
+#'   Coleman, James S. 1961. _The Adolescent Society_.
+#'   New York: Free Press.
 #'
-#' @description
-#'   A network of 36 Lord of the Rings book characters and 66 interactional relationships.
-#'   The ties are unweighted and concern only interaction.
-#'   Interaction can be cooperative or conflictual.
-#' @docType data
-#' @keywords datasets
-#' @name ison_lotr
-#' @usage data(ison_lotr)
+#'   Feld, Scott. 1991. “Why your friends have more friends than you do”
+#'   _American Journal of Sociology_ 96(6): 1464-1477.
+#'   \doi{10.1086/229693}.
 #' @format
 #'   ```{r, echo = FALSE}
-#'   ison_lotr
+#'   ison_adolescents
 #'   ```
-"ison_lotr"
+"ison_adolescents"
 
-# Laterals ####
-
-#' Two-mode projection examples (Hollway 2021)
-#'
-#' @description
-#'  These networks are for demonstration purposes and do not describe any real world network.
-#'  All examples contain named nodes.
-#'  The networks are gathered together as a list and can be retrieved simply by plucking 
-#'  the desired network.
-#' @docType data
-#' @keywords datasets
-#' @name ison_laterals
-#' @usage data(ison_laterals)
-#' @format
-#'   ```{r, echo = FALSE}
-#'   ison_laterals
-#'   ```
-"ison_laterals"
-
-# Algebra ####
+## Algebra ####
 
 #' Multiplex graph object of friends, social, and task ties (McFarland 2001)
 #'
@@ -111,34 +55,7 @@
 #'   ```
 "ison_algebra"
 
-# Adolescents ####
-
-#' One-mode subset of the adolescent society network (Coleman 1961)
-#'
-#' @description
-#'  One-mode subset of Coleman's adolescent society network (Coleman 1961),
-#'  as used in Feld's (1991) "Why your friends have more friends than you do".
-#'  Coleman collected data on friendships among students in 12 U.S. high schools.
-#'  Feld explored a subset of 8 girls from one of these schools, "Marketville",
-#'  and gave them fictitious names, which are retained here.
-#' @docType data
-#' @keywords datasets
-#' @name ison_adolescents
-#' @usage data(ison_adolescents)
-#' @references
-#'   Coleman, James S. 1961. _The Adolescent Society_.
-#'   New York: Free Press.
-#'
-#'   Feld, Scott. 1991. “Why your friends have more friends than you do”
-#'   _American Journal of Sociology_ 96(6): 1464-1477.
-#'   \doi{10.1086/229693}.
-#' @format
-#'   ```{r, echo = FALSE}
-#'   ison_adolescents
-#'   ```
-"ison_adolescents"
-
-# Karateka ####
+## Karateka ####
 
 #' One-mode karateka network (Zachary 1977)
 #'
@@ -165,7 +82,7 @@
 #'   ```
 "ison_karateka"
 
-# Koenigsberg ####
+## Koenigsberg ####
 
 #' One-mode Seven Bridges of Koenigsberg network (Euler 1741)
 #'
@@ -192,7 +109,26 @@
 #'   ```
 "ison_koenigsberg"
 
-# Networkers ####
+## Laterals ####
+
+#' Two-mode projection examples (Hollway 2021)
+#'
+#' @description
+#'  These networks are for demonstration purposes and do not describe any real world network.
+#'  All examples contain named nodes.
+#'  The networks are gathered together as a list and can be retrieved simply by plucking 
+#'  the desired network.
+#' @docType data
+#' @keywords datasets
+#' @name ison_laterals
+#' @usage data(ison_laterals)
+#' @format
+#'   ```{r, echo = FALSE}
+#'   ison_laterals
+#'   ```
+"ison_laterals"
+
+## Networkers ####
 
 #' One-mode EIES dataset (Freeman and Freeman 1979)
 #'
@@ -221,7 +157,7 @@
 #'   ```
 "ison_networkers"
 
-# Brandes ####
+## Brandes ####
 
 #' One-mode and two-mode centrality demonstration networks
 #'
@@ -239,7 +175,7 @@
 #'   ```
 "ison_brandes"
 
-# Southern Women ####
+## Southern Women ####
 
 #' Two-mode southern women (Davis, Gardner and Gardner 1941)
 #'
@@ -267,7 +203,7 @@
 #'   ```
 "ison_southern_women"
 
-# Lawfirm ####
+## Lawfirm ####
 
 #' One-mode lawfirm (Lazega 2001)
 #'
@@ -296,75 +232,7 @@
 #'   ```
 "ison_lawfirm"
 
-# Star Wars ####
-
-#' Seven one-mode Star Wars character interactions (Gabasova 2016)
-#'
-#' @description
-#' One-mode network dataset collected by Gabasova (2016)
-#' on the interactions between Star Wars characters in each movie from
-#' Episode 1 (The Phantom Menace) to Episode 7 (The Force Awakens).
-#' There is a separate network for each episode,
-#' and the data is listed in order from episode 1 to 7.
-#' The network for each episode varies in the number of nodes and ties.
-#' For all networks, characters are named (eg. R2-D2, Anakin, Chewbacca)
-#' and the following node attributes are provided where available:
-#' height, mass, hair color, skin color, eye color, birth year, sex, homeworld, and species.
-#' The node attribute 'faction' has also been added,
-#' denoting the faction (eg. Jedi, Rebel Alliance, etc) 
-#' that Star Wars characters belong to in each episode
-#' (coding completed with help of Yichen Shen and Tiphaine Aeby).
-#' Weighted ties represent the number of times characters speak 
-#' within the same scene of the film.
-#' @details
-#' The network for each episode may be extracted and used separately,
-#' eg. `ison_starwars[[1]]` or `ison_starwars$Episode I` for Episode 1.
-#' @docType data
-#' @keywords datasets
-#' @name ison_starwars
-#' @usage data(ison_starwars)
-#' @references
-#'   Gabasova, E. (2016).
-#'   \emph{Star Wars social network.}.
-#'   \doi{10.5281/zenodo.1411479}
-#' @format
-#'   ```{r, echo = FALSE}
-#'   ison_starwars
-#'   ```
-"ison_starwars"
-
-# Friends ####
-
-#' One-mode Friends character connections (McNulty, 2020)
-#'
-#' @description
-#' One-mode network collected by \href{https://github.com/keithmcnulty/friends_analysis/}{McNulty (2020)}
-#' on the connections between the Friends TV series characters
-#' from Seasons 1 to 10.
-#' The `ison_friends` is a directed network
-#' containing connections between characters organised by season number,
-#' which is reflected in the tie attribute 'wave'.
-#' The network contains 650 nodes
-#' Each tie represents the connection between a character pair (appear in the same scene),
-#' and the 'weight' of the tie is the number of scenes the character pair appears in together.
-#' For all networks, characters are named (eg. Phoebe, Ross, Rachel).
-#' @details
-#' The data contains both networks but each may be used separately.
-#' @docType data
-#' @keywords datasets
-#' @name ison_friends
-#' @usage data(ison_friends)
-#' @references
-#'   McNulty, K. (2020).
-#'   \emph{Network analysis of Friends scripts.}.
-#' @format
-#'   ```{r, echo = FALSE}
-#'   ison_friends
-#'   ```
-"ison_friends"
-
-
-# Physicians ####
+## Physicians ####
 
 #' Four multiplex one-mode physician diffusion data (Coleman, Katz, and Menzel, 1966)
 #'
@@ -416,37 +284,7 @@
 #'   ```
 "ison_physicians"
 
-# Harry Potter ####
-
-#' Six complex one-mode support data in Harry Potter books (Bossaert and Meidert 2013)
-#'
-#' @description
-#'   Goele Bossaert and Nadine Meidert coded peer support ties among 64 characters
-#'   in the Harry Potter books.
-#'   Each author coded four of seven books using NVivo, 
-#'   with the seventh book coded by both and serving to assess inter-rater reliability.
-#'   The first six books concentrated on adolescent interactions,
-#'   were studied in their paper, and are made available here.
-#'   The peer support ties mean voluntary emotional, instrumental, or informational support,
-#'   or praise from one living, adolescent character to another within the book's pages.
-#'   In addition, nodal attributes name, schoolyear (which doubles as their age),
-#'   gender, and their house assigned by the sorting hat are included.
-#' @docType data
-#' @keywords datasets
-#' @name ison_potter
-#' @usage data(ison_potter)
-#' @references
-#'   Bossaert, Goele and Nadine Meidert (2013). 
-#'   "'We are only as strong as we are united, as weak as we are divided'. A dynamic analysis of the peer support networks in the Harry Potter books." 
-#'   _Open Journal of Applied Sciences_, 3(2): 174-185.
-#'   \doi{10.4236/ojapps.2013.32024}
-#' @format
-#'   ```{r, echo = FALSE}
-#'   ison_potter
-#'   ```
-"ison_potter"
-
-# US States ####
+## US States ####
 
 #' One-mode undirected network of US state contiguity (Meghanathan 2017)
 #'
@@ -473,7 +311,7 @@
 "ison_usstates"
 
 
-# High-tech ####
+## High-tech ####
 
 #' One-mode multiplex, directed network of managers of a high-tech company (Krackhardt 1987)
 #'
@@ -506,19 +344,19 @@
 #'   ```
 "ison_hightech"
 
-# Monastery ####
+## Monks ####
 
-#' Three one-mode signed, weighted networks and a three-wave longitudinal network of monks (Sampson 1969)
+#' Multiplex network of three one-mode signed, weighted networks and a three-wave longitudinal network of monks (Sampson 1969)
 #'
 #' @description
 #'   The data were collected for an ethnographic study of community structure in a New England monastery. 
 #'   Various sociometric data was collected of the novices attending the minor seminary of 'Cloisterville' 
-#'   preparing to join the monastic order:
+#'   preparing to join the monastic order.
 #'   
-#'   - `ison_monastery_like` records whom novices said they liked most at three time points/waves
-#'   - `ison_monastery_esteem` records whom novices said they held in esteem (sign > 0) and disesteem (sign < 0)
-#'   - `ison_monastery_praise` records whom novices said they praised (sign > 0) and blamed (sign < 0)
-#'   - `ison_monastery_influence` records whom novices said were a positive influence (sign > 0) and negative influence (sign < 0)
+#'   - `type = "like"` records whom novices said they liked most at three time points/waves
+#'   - `type = "esteem"` records whom novices said they held in esteem (sign > 0) and disesteem (sign < 0)
+#'   - `type = "praise"` records whom novices said they praised (sign > 0) and blamed (sign < 0)
+#'   - `type = "influence"` records whom novices said were a positive influence (sign > 0) and negative influence (sign < 0)
 #'   
 #'   All networks are weighted.
 #'   Novices' first choices are weighted 3, the second 2, and third choices 1.
@@ -534,14 +372,14 @@
 #'   
 #'   Information about senior monks was not included.
 
-#'   While `ison_monastery_like` is observed over three waves,
+#'   While `type = "like"` is observed over three waves,
 #'   the rest of the data was recorded retrospectively from the end of the study,
 #'   after the network fragmented.
 #'   The waves in which the novitiates were expelled (1), voluntarily departed (2 and 3),
 #'   or remained (4) are given in the nodal attribute "left".
 #' @docType data
 #' @keywords datasets
-#' @name ison_monastery
+#' @name ison_monks
 #' @references
 #'   Sampson, Samuel F. 1969. _Crisis in a cloister_. 
 #'   Unpublished doctoral dissertation, Cornell University.
@@ -549,38 +387,200 @@
 #'   Breiger R., Boorman S. and Arabie P. 1975. 
 #'   "An algorithm for clustering relational data with applications to social network analysis and comparison with multidimensional scaling". 
 #'   _Journal of Mathematical Psychology_, 12: 328-383.
-#' @usage data(ison_monastery_like)
+#' @usage data(ison_monks)
 #' @format 
 #'   ```{r, echo = FALSE}
-#'   ison_monastery_like
+#'   ison_monks
 #'   ```
-"ison_monastery_like"
+"ison_monks"
 
-#' @rdname ison_monastery
-#' @usage data(ison_monastery_esteem)
+# Fictitious ####
+
+## Marvel ####
+
+#' Multilevel two-mode affiliation, signed one-mode networks of Marvel comic
+#' book characters (Yuksel 2017)
+#'
+#' @description
+#' This package includes two datasets related to the Marvel _comic book_ universe.
+#' The first, `ison_marvel_teams`,  is a two-mode affiliation network of 53
+#' Marvel comic book characters and their affiliations to 141 different teams.
+#' This network includes only information about nodes' names and nodeset,
+#' but additional nodal data can be taken from the other Marvel dataset here.
+#'
+#' The second network, `ison_marvel_relationships`, is a one-mode signed network
+#' of friendships and enmities between the 53 Marvel comic book characters.
+#' Friendships are indicated by a positive sign in the tie `sign` attribute,
+#' whereas enmities are indicated by a negative sign in this edge attribute.
+#' @details
+#' Additional nodal variables have been coded and included by Dr Umut Yuksel:
+#'
+#' - **Gender**: binary character, 43 "Male" and 10 "Female"
+#' - **PowerOrigin**: binary character, 2 "Alien", 1 "Cyborg", 5 "God/Eternal",
+#' 22 "Human", 1 "Infection", 16 "Mutant", 5 "Radiation", 1 "Robot"
+#' - **Appearances**: integer, in how many comic book issues they appeared in
+#' - **Attractive**: binary integer, 41 1 (yes) and 12 0 (no)
+#' - **Rich**: binary integer, 11 1 (yes) and 42 0 (no)
+#' - **Intellect**: binary integer, 39 1 (yes) and 14 0 (no)
+#' - **Omnilingual**: binary integer, 8 1 (yes) and 45 0 (no)
+#' - **UnarmedCombat**: binary integer, 51 1 (yes) and 2 0 (no)
+#' - **ArmedCombat**: binary integer, 25 1 (yes) and 28 0 (no)
+#' @docType data
+#' @keywords datasets
+#' @name ison_marvel
+#' @usage data(ison_marvel_teams)
+#' @source Umut Yuksel, 31 March 2017
 #' @format
 #'   ```{r, echo = FALSE}
-#'   ison_monastery_esteem
+#'   ison_marvel_teams
 #'   ```
-"ison_monastery_esteem"
+"ison_marvel_teams"
 
-#' @rdname ison_monastery
-#' @usage data(ison_monastery_influence)
-#' @format 
+#' @rdname ison_marvel
+#' @usage data(ison_marvel_relationships)
+#' @format
 #'   ```{r, echo = FALSE}
-#'   ison_monastery_influence
+#'   ison_marvel_relationships
 #'   ```
-"ison_monastery_influence"
+"ison_marvel_relationships"
 
-#' @rdname ison_monastery
-#' @usage data(ison_monastery_praise)
-#' @format 
+## Lord of the Rings ####
+
+#' One-mode network of Lord of the Rings character interactions
+#'
+#' @description
+#'   A network of 36 Lord of the Rings book characters and 66 interactional relationships.
+#'   The ties are unweighted and concern only interaction.
+#'   Interaction can be cooperative or conflictual.
+#' @docType data
+#' @keywords datasets
+#' @name ison_lotr
+#' @usage data(ison_lotr)
+#' @format
 #'   ```{r, echo = FALSE}
-#'   ison_monastery_praise
+#'   ison_lotr
 #'   ```
-"ison_monastery_praise"
+"ison_lotr"
 
-# Greys ####
+## Harry Potter ####
+
+#' Six complex one-mode support data in Harry Potter books (Bossaert and Meidert 2013)
+#'
+#' @description
+#'   Goele Bossaert and Nadine Meidert coded peer support ties among 64 characters
+#'   in the Harry Potter books.
+#'   Each author coded four of seven books using NVivo, 
+#'   with the seventh book coded by both and serving to assess inter-rater reliability.
+#'   The first six books concentrated on adolescent interactions,
+#'   were studied in their paper, and are made available here.
+#'   The peer support ties mean voluntary emotional, instrumental, or informational support,
+#'   or praise from one living, adolescent character to another within the book's pages.
+#'   In addition, nodal attributes name, schoolyear (which doubles as their age),
+#'   gender, and their house assigned by the sorting hat are included.
+#' @docType data
+#' @keywords datasets
+#' @name ison_potter
+#' @usage data(ison_potter)
+#' @references
+#'   Bossaert, Goele and Nadine Meidert (2013). 
+#'   "'We are only as strong as we are united, as weak as we are divided'. A dynamic analysis of the peer support networks in the Harry Potter books." 
+#'   _Open Journal of Applied Sciences_, 3(2): 174-185.
+#'   \doi{10.4236/ojapps.2013.32024}
+#' @format
+#'   ```{r, echo = FALSE}
+#'   ison_potter
+#'   ```
+"ison_potter"
+
+## Game of Thrones ####
+
+#' One-mode Game of Thrones kinship (Glander 2017)
+#'
+#' @description
+#'   Shirin Glander extended a data set on character deaths in the TV series Game of Thrones
+#'   with the kinship relationships between the characters, by scraping "A Wiki of Ice and Fire"
+#'   and adding missing information by hand.
+#' @docType data
+#' @keywords datasets
+#' @name ison_thrones
+#' @usage data(ison_thrones)
+#' @references
+#'   Glander, Shirin (2017). 
+#'   "\href{https://datascienceplus.com/network-analysis-of-game-of-thrones/}{Network analysis of Game of Thrones}".
+#' @format
+#'   ```{r, echo = FALSE}
+#'   ison_thrones
+#'   ```
+"ison_thrones"
+
+## Star Wars ####
+
+#' Seven one-mode Star Wars character interactions (Gabasova 2016)
+#'
+#' @description
+#' One-mode network dataset collected by Gabasova (2016)
+#' on the interactions between Star Wars characters in each movie from
+#' Episode 1 (The Phantom Menace) to Episode 7 (The Force Awakens).
+#' There is a separate network for each episode,
+#' and the data is listed in order from episode 1 to 7.
+#' The network for each episode varies in the number of nodes and ties.
+#' For all networks, characters are named (eg. R2-D2, Anakin, Chewbacca)
+#' and the following node attributes are provided where available:
+#' height, mass, hair color, skin color, eye color, birth year, sex, homeworld, and species.
+#' The node attribute 'faction' has also been added,
+#' denoting the faction (eg. Jedi, Rebel Alliance, etc) 
+#' that Star Wars characters belong to in each episode
+#' (coding completed with help of Yichen Shen and Tiphaine Aeby).
+#' Weighted ties represent the number of times characters speak 
+#' within the same scene of the film.
+#' @details
+#' The network for each episode may be extracted and used separately,
+#' eg. `ison_starwars[[1]]` or `ison_starwars$Episode I` for Episode 1.
+#' @docType data
+#' @keywords datasets
+#' @name ison_starwars
+#' @usage data(ison_starwars)
+#' @references
+#'   Gabasova, E. (2016).
+#'   \emph{Star Wars social network.}.
+#'   \doi{10.5281/zenodo.1411479}
+#' @format
+#'   ```{r, echo = FALSE}
+#'   ison_starwars
+#'   ```
+"ison_starwars"
+
+## Friends ####
+
+#' One-mode Friends character connections (McNulty, 2020)
+#'
+#' @description
+#' One-mode network collected by \href{https://github.com/keithmcnulty/friends_analysis/}{McNulty (2020)}
+#' on the connections between the Friends TV series characters
+#' from Seasons 1 to 10.
+#' The `ison_friends` is a directed network
+#' containing connections between characters organised by season number,
+#' which is reflected in the tie attribute 'wave'.
+#' The network contains 650 nodes
+#' Each tie represents the connection between a character pair (appear in the same scene),
+#' and the 'weight' of the tie is the number of scenes the character pair appears in together.
+#' For all networks, characters are named (eg. Phoebe, Ross, Rachel).
+#' @details
+#' The data contains both networks but each may be used separately.
+#' @docType data
+#' @keywords datasets
+#' @name ison_friends
+#' @usage data(ison_friends)
+#' @references
+#'   McNulty, K. (2020).
+#'   \emph{Network analysis of Friends scripts.}.
+#' @format
+#'   ```{r, echo = FALSE}
+#'   ison_friends
+#'   ```
+"ison_friends"
+
+## Greys ####
 
 #' One-mode undirected network of characters hook-ups on Grey's Anatomy TV show
 #'
