@@ -18,9 +18,10 @@
 #'    ```{r, echo = FALSE, cache = TRUE} 
 #'  knitr::kable(available_methods(c("to_mode1", "to_mode2", "to_ties")))
 #'  ```
-#' @name to_project
+#' @name manip_project
 #' @family modifications
-#' @inheritParams reformat
+#' @inheritParams manip_reformat
+#' @inheritParams manip_split
 #' @returns
 #'   All `to_` functions return an object of the same class as that provided. 
 #'   So passing it an igraph object will return an igraph object
@@ -28,7 +29,7 @@
 #'   with certain modifications as outlined for each function.
 NULL
 
-#' @rdname to_project
+#' @rdname manip_project
 #' @param similarity Method for establishing ties,
 #'   currently "count" (default), "jaccard", or "rand".
 #'   "count" calculates the number of coinciding ties,
@@ -102,7 +103,7 @@ to_mode1.data.frame <- function(.data, similarity = c("count","jaccard","rand","
   as_edgelist(to_mode1(as_matrix(.data), similarity = similarity))
 }
 
-#' @rdname to_project
+#' @rdname manip_project
 #' @export
 to_mode2 <- function(.data, similarity = c("count","jaccard","rand","pearson","yule")) UseMethod("to_mode2")
 
@@ -151,7 +152,7 @@ to_mode2.data.frame <- function(.data, similarity = c("count","jaccard","rand","
   as_edgelist(to_mode2(as_matrix(.data), similarity))
 }
 
-#' @rdname to_project
+#' @rdname manip_project
 #' @importFrom igraph make_line_graph E
 #' @examples
 #' to_ties(ison_adolescents)
@@ -187,7 +188,7 @@ to_ties.matrix <- function(.data){
   as_matrix(to_ties(as_igraph(.data)))
 }
 
-#' @rdname to_project
+#' @rdname manip_project
 #' @section Galois lattices: 
 #'   Note that the output from `to_galois()` is very busy at the moment.
 #' @export
@@ -212,6 +213,7 @@ to_galois <- function(.data) {
 #'   Transforming means that the returned object may have different dimensions
 #'   than the original object.
 #' 
+#'   - `to_ego()` scopes a network into the local neighbourhood of a given node.
 #'   - `to_giant()` scopes a network into one including only the main component and no smaller components or isolates.
 #'   - `to_no_isolates()` scopes a network into one excluding all nodes without ties
 #'   - `to_subgraph()` scopes a network into a subgraph by filtering on some node-related logical statement.
@@ -221,11 +223,11 @@ to_galois <- function(.data) {
 #'   Below are the currently implemented S3 methods:
 #'  
 #'    ```{r, echo = FALSE, cache = TRUE} 
-#'  knitr::kable(available_methods(c("to_giant", "to_no_isolates", "to_subgraph", "to_blocks")))
+#'  knitr::kable(available_methods(c("to_ego", "to_giant", "to_no_isolates", "to_subgraph", "to_blocks")))
 #'  ```
-#' @name to_scope
+#' @name manip_scope
 #' @family modifications
-#' @inheritParams reformat
+#' @inheritParams manip_reformat
 #' @returns
 #'   All `to_` functions return an object of the same class as that provided. 
 #'   So passing it an igraph object will return an igraph object
@@ -233,7 +235,30 @@ to_galois <- function(.data) {
 #'   with certain modifications as outlined for each function.
 NULL
 
-#' @rdname to_scope
+#' @rdname manip_scope
+#' @param node Name or index of node.
+#' @param max_dist The maximum breadth of the neighbourhood.
+#'   By default 1.
+#' @param min_dist The minimum breadth of the neighbourhood.
+#'   By default 0. 
+#'   Increasing this to 1 excludes the ego,
+#'   and 2 excludes ego's direct alters.
+#' @export
+to_ego <- function(.data, node, max_dist = 1, min_dist = 0) UseMethod("to_ego")
+
+#' @export
+to_ego.igraph <- function(.data, node, max_dist = 1, min_dist = 0){
+  egos <- to_egos(.data, max_dist = max_dist, min_dist = min_dist)
+  as_igraph(egos[[node]])
+}
+
+#' @export
+to_ego.tbl_graph <- function(.data, node, max_dist = 1, min_dist = 0){
+  egos <- to_egos(.data, max_dist = max_dist, min_dist = min_dist)
+  as_tidygraph(egos[[node]])
+}
+
+#' @rdname manip_scope
 #' @export
 to_giant <- function(.data) UseMethod("to_giant")
 
@@ -266,7 +291,7 @@ to_giant.matrix <- function(.data) {
   as_matrix(to_giant(as_igraph(.data)))
 }
 
-#' @rdname to_scope
+#' @rdname manip_scope
 #' @importFrom tidygraph node_is_isolated
 #' @importFrom dplyr filter
 #' @examples
@@ -313,7 +338,7 @@ to_no_isolates.data.frame <- function(.data) {
   as_edgelist(to_no_isolates(as_tidygraph(.data)))
 }
 
-#' @rdname to_scope
+#' @rdname manip_scope
 #' @param ... Arguments passed on to dplyr::filter
 #' @importFrom dplyr filter
 #' @export
@@ -345,7 +370,7 @@ to_subgraph.matrix <- function(.data, ...){
   as_matrix(to_subgraph(as_tidygraph(.data), ...))
 }
 
-#' @rdname to_scope
+#' @rdname manip_scope
 #' @section `to_blocks()`: 
 #'   Reduced graphs provide summary representations of network structures 
 #'   by collapsing groups of connected nodes into single nodes 
@@ -431,9 +456,9 @@ to_blocks.tbl_graph <- function(.data, membership, FUN = mean){
 #'   ```{r, echo = FALSE, cache = TRUE} 
 #'   knitr::kable(available_methods(c("to_matching", "to_mentoring", "to_eulerian", "to_tree")))
 #'   ```
-#' @name to_paths
+#' @name manip_paths
 #' @family modifications
-#' @inheritParams reformat
+#' @inheritParams manip_reformat
 #' @returns
 #'   All `to_` functions return an object of the same class as that provided. 
 #'   So passing it an igraph object will return an igraph object
@@ -441,7 +466,7 @@ to_blocks.tbl_graph <- function(.data, membership, FUN = mean){
 #'   with certain modifications as outlined for each function.
 NULL
 
-#' @rdname to_paths
+#' @rdname manip_paths
 #' @section `to_matching()`:
 #'   `to_matching()` uses `{igraph}`'s `max_bipartite_match()`
 #'   to return a network in which each node is only tied to
@@ -471,7 +496,7 @@ to_matching <- function(.data, mark = "type") UseMethod("to_matching")
 #' @export
 to_matching.igraph <- function(.data, mark = "type"){
   if(length(unique(node_attribute(.data, mark)))>2)
-    stop("This function currently only works with binary attributes.")
+    cli::cli_abort("This function currently only works with binary attributes.")
   el <- igraph::max_bipartite_match(.data, 
                  types = node_attribute(.data, mark))$matching
   el <- data.frame(from = names(el), to = el)
@@ -501,7 +526,7 @@ to_matching.matrix <- function(.data, mark = "type"){
   as_matrix(to_matching(as_igraph(.data), mark))
 }
 
-#' @rdname to_paths 
+#' @rdname manip_paths 
 #' @param elites The proportion of nodes to be selected as mentors.
 #'   By default this is set at 0.1.
 #'   This means that the top 10% of nodes in terms of degree,
@@ -565,7 +590,7 @@ to_mentoring.igraph <- function(.data, elites = 0.1){
   as_igraph(out)
 }
 
-#' @rdname to_paths
+#' @rdname manip_paths
 #' @importFrom igraph eulerian_path
 #' @examples
 #'   to_eulerian(delete_nodes(ison_koenigsberg, "Lomse"))
@@ -576,7 +601,7 @@ to_eulerian <- function(.data) UseMethod("to_eulerian")
 #' @export
 to_eulerian.igraph <- function(.data){
   if(!is_eulerian(.data))
-    stop("This is not a Eulerian graph.")
+    cli::cli_abort("This is not a Eulerian graph.")
   out <- paste(attr(igraph::eulerian_path(.data)$vpath, "names"), 
                collapse = "-+")
   out <- create_explicit(out)
@@ -586,14 +611,14 @@ to_eulerian.igraph <- function(.data){
 #' @export
 to_eulerian.tbl_graph <- function(.data){
   if(!is_eulerian(.data))
-    stop("This is not a Eulerian graph.")
+    cli::cli_abort("This is not a Eulerian graph.")
   out <- paste(attr(igraph::eulerian_path(.data)$vpath, "names"), 
                collapse = "-+")
   out <- create_explicit(out)
   out
 }
 
-#' @rdname to_paths 
+#' @rdname manip_paths 
 #' @export
 to_tree <- function(.data) {
   .data <- as_igraph(.data)
