@@ -21,7 +21,7 @@
 #'   - `net_spatial()` measures the spatial association/autocorrelation 
 #'   (global Moran's I) in a network.
 #'   
-#' @inheritParams is
+#' @inheritParams mark_is
 #' @param attribute Name of a nodal attribute or membership vector
 #'   to use as categories for the diversity measure.
 #' @param clusters A nodal cluster membership vector or name of a vertex attribute.
@@ -94,7 +94,7 @@ net_diversity <- function(.data, attribute, clusters = NULL){
                       numeric(1))
     names(blauout) <- paste0("Cluster ", unique(clu))
     blauout <- blauout[order(names(blauout))]
-  } else stop("`clusters` must be the name of a nodal variable in the object.")
+  } else cli::cli_abort("`clusters` must be the name of a nodal variable in the object.")
   make_network_measure(blauout, .data)
 }
 
